<?php
/**
 * @file
 * Gardengnome player field formatter.
 */

/**
 * Implements hook_field_formatter_info().
 *
 * Provide a formatter for gardengnome packages.
 */
function gardengnome_player_field_formatter_info() {
  $formatters = array();
  $formatters['gardengnome_package'] = array(
    'label' => t('Gardengnome Package'),
    'field types' => array('gardengnome_package'),
    'settings' => array(
      'preview_style' => 'none',
      'display_style' => 'inline',
      'autoplay' => 0,
      'prefer_flash' => 0,
      'use_iframe' => 1
    ),
  );
  return $formatters;
}

/**
 * Implements hook_field_formatter_view().
 */
function gardengnome_player_field_formatter_view($entity_type, $entity, $field, $instance, $langcode, $items, $display) {
  $element = array();
  $settings = $display['settings'];
  foreach ($items as $delta => $item) {
    $element[$delta] = array(
      '#markup' => theme('gardengnome_player', array(
        'package' => $item['uri'],
        'preview_style' => $settings['preview_style'],
        'display_style' => $settings['display_style'],
        'autoplay' => $settings['autoplay'],
        'prefer_flash' => $settings['prefer_flash'],
        'use_iframe' => $settings['use_iframe'],
      )),
    );
  }
  return $element;
}

/**
 * Implements hook_field_formatter_settings_form().
 */
function gardengnome_player_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state) {
  $settings = $instance['display'][$view_mode]['settings'];

  $element = array();
  $element['preview_style'] = array(
    '#type' => 'select',
    '#title' => t('Preview image style'),
    '#description' => t('Choose an image style for the preview image. Inline displays will inherit it\'s size.'),
    '#options' => array(
      'none' => t('None (original image)'),
    ),
    '#default_value' => isset($settings['preview_style']) ? $settings['preview_style'] : 'none',
  );

  foreach (image_styles() as $key => $style) {
    $element['preview_style']['#options'][$key] = $style['label'];
  }

  $element['display_style'] = array(
    '#type' => 'select',
    '#title' => t('Display style'),
    '#description' => t('Choose a display style. <em>Inline</em> will inherit the preview images size. </em><strong>Do not use <em>Inline autoplay</em> if many items are displayed on one page!</strong>'),
    '#options' => array(
      'popup' => t('Popup'),
      'inline' => t('Inline'),
    ),
    '#default_value' => isset($settings['display_style']) ? $settings['display_style'] : 'blank',
  );

  $element['autoplay'] = array(
    '#type' => 'checkbox',
    '#title' => t('Autoplay'),
    '#description' => t('Start the player on page load. Popup displays always start immediatly.'),
    '#default_value' => isset($settings['autoplay']) ? $settings['autoplay'] : FALSE,
  );

  $element['prefer_flash'] = array(
    '#type' => 'checkbox',
    '#title' => t('Prefer flash'),
    '#description' => t('Use flash player, even if the device is capable of displaying WebGL/CSS3D.'),
    '#default_value' => isset($settings['prefer_flash']) ? $settings['prefer_flash'] : FALSE,
  );

  $element['use_iframe'] = array(
    '#type' => 'checkbox',
    '#title' => t('Display in iframe'),
    '#description' => t('If not displayed in an iframe (this option <em>unchecked</em>, your websites styles may interfere with player display. <strong>If displayed in an iframe, fullscreen on iPad won\'t work!</strong>'),
    '#default_value' => isset($settings['use_iframe']) ? $settings['use_iframe'] : FALSE,
  );

  return $element;
}

/**
 * Implements hook_field_formatter_settings_summary().
 */
function gardengnome_player_field_formatter_settings_summary($field, $instance, $view_mode) {
  $settings = $instance['display'][$view_mode]['settings'];
  $styles = array('none' => 'original');
  if (module_exists('image')) {
    foreach (image_styles() as $key => $style) {
      $styles[$key] = $style['name'];
    }
  }
  $displays = array(
    'popup' => t('in a popup window'),
    'inline' => t('inline'),
  );
  $summary = t('Preview as %style image and play %display.', array(
    '%style' => $styles[$settings['preview_style']],
    '%display' => $displays[$settings['display_style']],
  ));
  return $summary;
}
